@@ -33,15 +33,37 @@
 #' @param n_allocated a character string specifying the name of the
 #' column in \code{design_data} that indicates the n allocated to each
 #' stratum. Defaults to "n_to_sample".
+#' @param probs a character string specifying the name of the column in
+#' in \code{design_data} that indicates the sampling probability for each
+#' stratum, or a formula indicating how the sampling probabilities can be
+#' computed. From existing columns.
+#' If specified, a new column containing the sampling probability
+#' attached to each sampled unit will be created in the outputted
+#' dataframe. This column will be named "sampling_prob". Defaults to NULL.
+#' @param wave A numeric value or character string indicating the
+#' sampling wave. If specified, the input is appended to
+#' "sample_indicator" in the new the sample indicator column name
+#' (as long as such columns name do not already exist in \code{data}).
+#' Defaults to NULL. This argument does not
+#' apply when \code{sample_strata()} is called inside \code{allocate_wave()}.
+#' @param warn_prob_overwrite Logical indicator for whether warning should
+#' be printed if \code{probs} is specified and a "sampling_prob" columns is
+#' going to be overwritten. Defaults to TRUE. If function is called inside
+#' \code{apply_multiwave()}, then defaults to FALSE
 #' @export
 #' @return returns \code{data} as a dataframe with a new column named
 #' "sample_indicator" containing a binary (1/0) indicator of
-#' whether each unit should be sampled.
+#' whether each unit should be sampled. If \code{wave} argument is
+#' specified, then the given input is appended to the name "sample_indicator".
+#' If \code{probs} argument is specified, then the dataframe will also contain
+#' a new column named "sampling_prob" holding the sampling probabilities for
+#' each sampled element.
 #' @importFrom magrittr %>%
 #' @examples
 #' # Define a design dataframe
 #' design <- data.frame(
 #'   strata = c("setosa", "virginica", "versicolor"),
+#'   npop = c(50, 50, 50),
 #'   n_to_sample = c(5, 5, 5)
 #' )
 #'
@@ -51,7 +73,15 @@
 #' # Run
 #' sample_strata(
 #'   data = iris, strata = "Species", id = "id",
-#'   design_data = design, design_strata = "strata", n_allocated = "n_to_sample"
+#'   design_data = design, design_strata = "strata",
+#'   n_allocated = "n_to_sample"
+#' )
+#'
+#' # To include probs as a formula
+#' sample_strata(
+#'   data = iris, strata = "Species", id = "id",
+#'   design_data = design, design_strata = "strata",
+#'   n_allocated = "n_to_sample", probs = ~n_to_sample/npop
 #' )
 #'
 #' # If some units had already been sampled
@@ -60,11 +90,13 @@
 #' sample_strata(
 #'   data = iris, strata = "Species", id = "id",
 #'   already_sampled = "already_sampled",
-#'   design_data = design, design_strata = "strata", n_allocated = "n_to_sample"
+#'   design_data = design, design_strata = "strata",
+#'   n_allocated = "n_to_sample"
 #' )
 sample_strata <- function(data, strata, id, already_sampled = NULL,
                           design_data, design_strata = "strata",
-                          n_allocated = "n_to_sample") {
+                          n_allocated = "n_to_sample", probs = NULL,
+                          wave = NULL, warn_prob_overwrite = TRUE) {
   if (is.matrix(data) | is.matrix(design_data)) {
     data <- as.data.frame(data)
     design_data <- as.data.frame(design_data)
@@ -99,6 +131,30 @@ sample_strata <- function(data, strata, id, already_sampled = NULL,
     containing only whole number values")
   }
   nsample <- sum(design_data[, n_allocated])
+
+  if(is.null(probs) == FALSE){
+    if (is(probs, "formula")){
+      # Check if variables exist in the dataframe
+      if (!all(all.vars(probs) %in% names(design_data))) {
+        stop("Variables in probs formula must exist in design_data.")
+      }
+
+      # Evaluate the formula and create the new column
+      probs_expr <- as.character(probs)[[2]]
+      design_data <- design_data %>%
+        dplyr::mutate(probs := !!rlang::parse_expr(probs_expr))
+      probs <- "probs"
+    }
+    if (probs %in% names(design_data) == FALSE) {
+      stop("If not NULL, 'probs' must be a character string matching
+      a column name of 'design_data'.")
+    }
+    if (is.numeric(design_data[, probs]) == FALSE) {
+      stop("If not NULL,
+           'probs' must specify a numeric column in 'design_data'")
+    }
+  }
+
   if (is.null(already_sampled) == FALSE) {
     if (already_sampled %in% names(data) == FALSE) {
       stop("If not NULL, 'already_sampled' must be a character string matching
@@ -150,7 +206,35 @@ sample_strata <- function(data, strata, id, already_sampled = NULL,
   }
   sampled_ids <- unlist(sampled_ids)
   names(data)[names(data) == id] <- "id"
+
+  ## Generate sample_indicator column, possibly with "wave" arg appended
+
+  new_col_name <- paste0("sample_indicator", wave)
+  new_col_name <- ifelse(new_col_name %in% names(data),
+                         "sample_indicator",
+                         new_col_name)
+
   output_df <- data %>%
-    dplyr::mutate(sample_indicator = ifelse(id %in% sampled_ids, 1, 0))
+    dplyr::mutate(!!new_col_name := ifelse(id %in% sampled_ids, 1, 0))
+
+  ## If 'probs' specified, add sampling_prob column for sampled units only
+
+  if(!is.null(probs)){
+    if("sampling_prob" %in% names(output_df)){
+      if(warn_prob_overwrite == TRUE){
+      warning("Overwriting prior 'sampling_prob' column with
+              new sampling probs" )
+    }
+      output_df <- output_df[,!(names(output_df) == "sampling_prob")]
+    }
+    temp <- design_data[,c(design_strata, probs)]
+    names(temp) <- c(strata, "sampling_prob")
+    sampling_prob <- NULL # to avoid global var note, ensure next line works
+    output_df <- output_df %>%
+      dplyr::left_join(temp, by = strata) %>%
+      dplyr::mutate(sampling_prob = ifelse(id %in% sampled_ids,
+                                              sampling_prob, NA))
+  }
+
   return(output_df)
 }
