@@ -14,8 +14,8 @@ iris$Sepal.Width <- iris$Sepal.Length + rnorm(60, 0, 0.5)
 # 1. Optimum_allocation
 
 test_that("optimum_allocation runs with args provided", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     dplyr::select(iris, -Sepal.Width)
   MySurvey <- apply_multiwave(MySurvey,
     phase = 2, wave = 1,
@@ -26,14 +26,14 @@ test_that("optimum_allocation runs with args provided", {
     allow.na = FALSE
   )
   expect_equal(
-    dim(get_data(MySurvey,
+    dim(get_mw(MySurvey,
       phase = 2, wave = 1,
       slot = "design"
     )),
     c(3, 6)
   )
   expect_equal(
-    sum(get_data(MySurvey,
+    sum(get_mw(MySurvey,
       phase = 2, wave = 1,
       slot = "design"
     )$stratum_size),
@@ -46,7 +46,7 @@ test_that("optimum_allocation runs with args provided", {
     method = "Neyman"
   )
   expect_equal(
-    dim(get_data(MySurvey,
+    dim(get_mw(MySurvey,
       phase = 2, wave = 1,
       slot = "design"
     )),
@@ -55,10 +55,10 @@ test_that("optimum_allocation runs with args provided", {
 })
 
 test_that("optimum_allocation runs with args in metadata", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     dplyr::select(iris, -Sepal.Width)
-  get_data(MySurvey, phase = NA, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = NA, slot = "metadata") <- list(
     strata = "Species",
     nsample = 15,
     y = "Sepal.Length",
@@ -71,14 +71,14 @@ test_that("optimum_allocation runs with args in metadata", {
     fun = "optimum_allocation"
   )
   expect_equal(
-    dim(get_data(MySurvey,
+    dim(get_mw(MySurvey,
       phase = 2, wave = 1,
       slot = "design"
     )),
     c(3, 6)
   )
   expect_equal(
-    sum(get_data(MySurvey,
+    sum(get_mw(MySurvey,
       phase = 2, wave = 1,
       slot = "design"
     )$stratum_size),
@@ -86,7 +86,7 @@ test_that("optimum_allocation runs with args in metadata", {
   )
 
   # but metadata in phase overrides
-  get_data(MySurvey, phase = 2, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = 2, slot = "metadata") <- list(
     strata = "Species",
     nsample = 20,
     y = "Sepal.Length",
@@ -98,14 +98,14 @@ test_that("optimum_allocation runs with args in metadata", {
     fun = "optimum_allocation"
   )
   expect_equal(
-    dim(get_data(MySurvey,
+    dim(get_mw(MySurvey,
       phase = 2, wave = 1,
       slot = "design"
     )),
     c(3, 6)
   )
   expect_equal(
-    sum(get_data(MySurvey,
+    sum(get_mw(MySurvey,
       phase = 2, wave = 1,
       slot = "design"
     )$stratum_size),
@@ -113,7 +113,7 @@ test_that("optimum_allocation runs with args in metadata", {
   )
 
   # And wave overrides that
-  get_data(MySurvey,
+  set_mw(MySurvey,
     phase = 2, wave = 1,
     slot = "metadata"
   ) <- list(
@@ -128,14 +128,14 @@ test_that("optimum_allocation runs with args in metadata", {
     fun = "optimum_allocation"
   )
   expect_equal(
-    dim(get_data(MySurvey,
+    dim(get_mw(MySurvey,
       phase = 2, wave = 1,
       slot = "design"
     )),
     c(3, 6)
   )
   expect_equal(
-    sum(get_data(MySurvey,
+    sum(get_mw(MySurvey,
       phase = 2, wave = 1,
       slot = "design"
     )$stratum_size),
@@ -144,8 +144,8 @@ test_that("optimum_allocation runs with args in metadata", {
 })
 
 test_that("optimum_allocation works for wave 2 also", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-  get_data(MySurvey, phase = 2, wave = 1, slot = "data") <- iris
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "data") <- iris
   MySurvey <- apply_multiwave(MySurvey,
     phase = 2, wave = 2,
     fun = "optimum_allocation", strata = "Species",
@@ -156,7 +156,7 @@ test_that("optimum_allocation works for wave 2 also", {
     allow.na = FALSE
   )
   expect_equal(
-    dim(get_data(MySurvey,
+    dim(get_mw(MySurvey,
       phase = 2, wave = 2,
       slot = "design"
     )),
@@ -167,18 +167,18 @@ test_that("optimum_allocation works for wave 2 also", {
 # 2. Allocate_wave
 
 test_that("allocate_wave runs with args provided", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     dplyr::select(iris, -Sepal.Width)
 
-  get_data(MySurvey, phase = 2, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = 2, slot = "metadata") <- list(
     strata = "Species",
     design_strata = "strata",
     id = "id",
     n_allocated = "n_to_sample"
   )
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(strata = unique(iris$Species), n_to_sample = c(5, 5, 5))
   set.seed(123)
   MySurvey <- apply_multiwave(MySurvey,
@@ -186,37 +186,36 @@ test_that("allocate_wave runs with args provided", {
     fun = "sample_strata"
   )
 
-  samples <- get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
+  samples <- get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "sampled_data") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "sampled_data") <-
     dplyr::select(iris, id, Sepal.Width)[samples, ]
   MySurvey <- merge_samples(MySurvey,
-    phase = 2, wave = 1, id = "id",
-    sampled_ind = "already_sampled_ind"
+    phase = 2, wave = 1, id = "id"
   )
   MySurvey <- apply_multiwave(MySurvey,
     phase = 2, wave = 2,
     fun = "allocate_wave", strata = "Species",
     y = "Sepal.Width",
-    already_sampled = "already_sampled_ind",
+    already_sampled = "sampled_phase2",
     nsample = 30, detailed = TRUE
   )
   expect_equal(
-    dim(get_data(MySurvey,
+    dim(get_mw(MySurvey,
       phase = 2, wave = 2,
       slot = "design"
     )),
     c(3, 7)
   )
   expect_equal(
-    sum(get_data(MySurvey,
+    sum(get_mw(MySurvey,
       phase = 2, wave = 1,
       slot = "design"
     )$n_to_sample),
     15
   )
   expect_equal(
-    sum(get_data(MySurvey,
+    sum(get_mw(MySurvey,
                  phase = 2, wave = 2,
                  slot = "design"
     )$n_to_sample),
@@ -226,19 +225,19 @@ test_that("allocate_wave runs with args provided", {
                               phase = 2, wave = 2,
                               fun = "allocate_wave", strata = "Species",
                               y = "Sepal.Width",
-                              already_sampled = "already_sampled_ind",
+                              already_sampled = "sampled_phase2",
                               allocation_method = "Neyman",
                               nsample = 30, detailed = TRUE
   )
   expect_lt(
-    sum(get_data(MySurvey,
+    sum(get_mw(MySurvey,
                  phase = 2, wave = 2,
                  slot = "design"
     )$n_to_sample),
     33
   )
   expect_gt(
-    sum(get_data(MySurvey,
+    sum(get_mw(MySurvey,
                  phase = 2, wave = 2,
                  slot = "design"
     )$n_to_sample),
@@ -247,11 +246,11 @@ test_that("allocate_wave runs with args provided", {
 })
 
 test_that("allocate_wave runs with args in metadata", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     dplyr::select(iris, -Sepal.Width)
 
-  get_data(MySurvey, phase = 2, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = 2, slot = "metadata") <- list(
     strata = "Species",
     design_strata = "strata",
     id = "id",
@@ -259,7 +258,7 @@ test_that("allocate_wave runs with args in metadata", {
     allocation_method = "WrightII"
   )
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(strata = unique(iris$Species), n_to_sample = c(5, 5, 5))
   set.seed(123)
   MySurvey <- apply_multiwave(MySurvey,
@@ -267,44 +266,43 @@ test_that("allocate_wave runs with args in metadata", {
     fun = "sample_strata"
   )
 
-  samples <- get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
+  samples <- get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "sampled_data") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "sampled_data") <-
     dplyr::select(iris, id, Sepal.Width)[samples, ]
   MySurvey <- merge_samples(MySurvey,
-    phase = 2, wave = 1, id = "id",
-    sampled_ind = "already_sampled_ind"
+    phase = 2, wave = 1, id = "id"
   )
-  get_data(MySurvey, phase = NA, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = NA, slot = "metadata") <- list(
     y = "Sepal.Width",
-    already_sampled = "already_sampled_ind",
+    already_sampled = "sampled_phase2",
     strata = "Species",
     nsample = 30, detailed = TRUE
   )
-  get_data(MySurvey, phase = 2, wave = 2, slot = "metadata") <- list()
-  get_data(MySurvey, phase = 2, slot = "metadata") <- list()
+  set_mw(MySurvey, phase = 2, wave = 2, slot = "metadata") <- list()
+  set_mw(MySurvey, phase = 2, slot = "metadata") <- list()
   MySurvey <- apply_multiwave(MySurvey,
     phase = 2, wave = 2,
     fun = "allocate_wave"
   )
   expect_equal(
-    dim(get_data(MySurvey,
+    dim(get_mw(MySurvey,
       phase = 2, wave = 2,
       slot = "design"
     )),
     c(3, 7)
   )
   expect_equal(
-    sum(get_data(MySurvey,
+    sum(get_mw(MySurvey,
       phase = 2, wave = 2,
       slot = "design"
     )$n_to_sample),
     30
   )
   # but metadata in phase overrides
-  get_data(MySurvey, phase = 2, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = 2, slot = "metadata") <- list(
     y = "Sepal.Width",
-    already_sampled = "already_sampled_ind",
+    already_sampled = "sampled_phase2",
     strata = "Species",
     nsample = 32, detailed = TRUE, allocation_method = "WrightII"
   )
@@ -313,14 +311,14 @@ test_that("allocate_wave runs with args in metadata", {
     fun = "allocate_wave"
   )
   expect_equal(
-    dim(get_data(MySurvey,
+    dim(get_mw(MySurvey,
       phase = 2, wave = 2,
       slot = "design"
     )),
     c(3, 7)
   )
   expect_equal(
-    sum(get_data(MySurvey,
+    sum(get_mw(MySurvey,
       phase = 2, wave = 2,
       slot = "design"
     )$n_to_sample),
@@ -328,12 +326,12 @@ test_that("allocate_wave runs with args in metadata", {
   )
 
   # And wave overrides that
-  get_data(MySurvey,
+  set_mw(MySurvey,
     phase = 2, wave = 2,
     slot = "metadata"
   ) <- list(
     y = "Sepal.Width",
-    already_sampled = "already_sampled_ind",
+    already_sampled = "sampled_phase2",
     strata = "Species",
     nsample = 33, detailed = TRUE, allocation_method = "WrightII"
   )
@@ -342,14 +340,14 @@ test_that("allocate_wave runs with args in metadata", {
     fun = "allocate_wave"
   )
   expect_equal(
-    dim(get_data(MySurvey,
+    dim(get_mw(MySurvey,
       phase = 2, wave = 2,
       slot = "design"
     )),
     c(3, 7)
   )
   expect_equal(
-    sum(get_data(MySurvey,
+    sum(get_mw(MySurvey,
       phase = 2, wave = 2,
       slot = "design"
     )$n_to_sample),
@@ -358,8 +356,8 @@ test_that("allocate_wave runs with args in metadata", {
 })
 
 test_that("error if phase = 1", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     dplyr::select(iris, -Sepal.Width)
   expect_error(
     apply_multiwave(MySurvey,
@@ -371,18 +369,18 @@ test_that("error if phase = 1", {
 })
 
 test_that("errors if args are not specified", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     dplyr::select(iris, -Sepal.Width)
 
-  get_data(MySurvey, phase = 2, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = 2, slot = "metadata") <- list(
     strata = "Species",
     design_strata = "strata",
     id = "id",
     n_allocated = "n_to_sample"
   )
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(strata = unique(iris$Species), n_to_sample = c(5, 5, 5))
   set.seed(123)
   MySurvey <- apply_multiwave(MySurvey,
@@ -390,15 +388,14 @@ test_that("errors if args are not specified", {
     fun = "sample_strata"
   )
 
-  samples <- get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
+  samples <- get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "sampled_data") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "sampled_data") <-
     dplyr::select(iris, id, Sepal.Width)[samples, ]
   MySurvey <- merge_samples(MySurvey,
-    phase = 2, wave = 1, id = "id",
-    sampled_ind = "already_sampled_ind"
+    phase = 2, wave = 1, id = "id"
   )
-  get_data(MySurvey, phase = 2, slot = "metadata") <- list()
+  set_mw(MySurvey, phase = 2, slot = "metadata") <- list()
 
   expect_error(
     apply_multiwave(MySurvey,
@@ -448,11 +445,11 @@ test_that("errors if args are not specified", {
 # 3. sample_strata
 
 test_that("sample_strata works with specified args", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     dplyr::select(iris, -Sepal.Width)
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(strata = unique(iris$Species), n_to_sample = c(5, 5, 5))
   set.seed(123)
   MySurvey <- apply_multiwave(MySurvey,
@@ -463,23 +460,32 @@ test_that("sample_strata works with specified args", {
     n_allocated = "n_to_sample"
   )
   expect_equal(length(
-    get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
+    get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
   ), 15)
+
+  # And that newly created column in data slot is good
+  # expect_equal(names(get_mw(MySurvey, phase = 2, wave = 1, slot = "data"))[4],
+  #             "sample_indicatorWave1")
+  # expect_equivalent(
+  #  as.character(
+  #    dplyr::filter(get_mw(MySurvey, phase = 2, wave = 1, slot = "data"),
+  #                sample_indicatorWave1 == 1)$id),
+  #  get_mw(MySurvey, phase = 2, wave = 1, slot = "samples"))
 })
 
 test_that("sample_strata works with args specified in metadata", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     dplyr::select(iris, -Sepal.Width)
 
-  get_data(MySurvey, phase = NA, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = NA, slot = "metadata") <- list(
     strata = "Species",
     design_strata = "strata",
     id = "id",
     n_allocated = "n_to_sample"
   )
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(strata = unique(iris$Species), n_to_sample = c(5, 5, 5))
   set.seed(123)
   MySurvey <- apply_multiwave(MySurvey,
@@ -487,18 +493,18 @@ test_that("sample_strata works with args specified in metadata", {
     fun = "sample_strata"
   )
   expect_equal(length(
-    get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
+    get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
   ), 15)
 
   # only need to specify strata once if it is same in both
 
-  get_data(MySurvey, phase = NA, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = NA, slot = "metadata") <- list(
     strata = "Species",
     id = "id",
     n_allocated = "n_to_sample"
   )
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(Species = unique(iris$Species), n_to_sample = c(5, 5, 5))
   set.seed(123)
   MySurvey <- apply_multiwave(MySurvey,
@@ -506,18 +512,18 @@ test_that("sample_strata works with args specified in metadata", {
     fun = "sample_strata"
   )
   expect_equal(length(
-    get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
+    get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
   ), 15)
 
   # but metadata in phase overrides
-  get_data(MySurvey, phase = 2, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = 2, slot = "metadata") <- list(
     strata = "Species",
     design_strata = "strata",
     id = "id",
     n_allocated = "n_to_sample"
   )
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(strata = unique(iris$Species), n_to_sample = c(6, 5, 5))
   set.seed(123)
   MySurvey <- apply_multiwave(MySurvey,
@@ -525,18 +531,18 @@ test_that("sample_strata works with args specified in metadata", {
     fun = "sample_strata"
   )
   expect_equal(length(
-    get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
+    get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
   ), 16)
 
   # again, only need to specify strata once if it is same in both
 
-  get_data(MySurvey, phase = 2, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = 2, slot = "metadata") <- list(
     strata = "Species",
     id = "id",
     n_allocated = "n_to_sample"
   )
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(Species = unique(iris$Species), n_to_sample = c(6, 5, 5))
   set.seed(123)
   MySurvey <- apply_multiwave(MySurvey,
@@ -544,18 +550,18 @@ test_that("sample_strata works with args specified in metadata", {
     fun = "sample_strata"
   )
   expect_equal(length(
-    get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
+    get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
   ), 16)
 
   # And wave overrides that
-  get_data(MySurvey, phase = 2, wave = 1, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "metadata") <- list(
     strata = "Species",
     design_strata = "strata",
     id = "id",
     n_allocated = "n_to_sample"
   )
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(strata = unique(iris$Species), n_to_sample = c(6, 6, 5))
   set.seed(123)
   MySurvey <- apply_multiwave(MySurvey,
@@ -563,18 +569,18 @@ test_that("sample_strata works with args specified in metadata", {
     fun = "sample_strata"
   )
   expect_equal(length(
-    get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
+    get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
   ), 17)
 
   # only need to specify strata once if it is same in both
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "metadata") <- list(
     strata = "Species",
     id = "id",
     n_allocated = "n_to_sample"
   )
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(Species = unique(iris$Species), n_to_sample = c(7, 5, 5))
   set.seed(123)
   MySurvey <- apply_multiwave(MySurvey,
@@ -582,17 +588,17 @@ test_that("sample_strata works with args specified in metadata", {
     fun = "sample_strata"
   )
   expect_equal(length(
-    get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
+    get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
   ), 17)
 })
 
 test_that("errors in sample_strata if args don't match", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     dplyr::select(iris, -Sepal.Width)
 
   # If empty design
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame()
   set.seed(123)
   expect_error(
@@ -607,10 +613,10 @@ test_that("errors in sample_strata if args don't match", {
   )
 
   # If empty data
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     data.frame()
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(strata = unique(iris$Species), n_to_sample = c(5, 5, 5))
 
 
@@ -625,7 +631,7 @@ test_that("errors in sample_strata if args don't match", {
     "of previous wave must contain data to be used"
   )
 
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     dplyr::select(iris, -Sepal.Width)
 
   expect_error(
@@ -683,12 +689,12 @@ test_that("errors in sample_strata if args don't match", {
 # 4. merge_samples
 
 test_that("merge_samples works when args are specified within it", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
 
-  get_data(MySurvey, phase = 1, slot = "data") <-
+  set_mw(MySurvey, phase = 1, slot = "data") <-
     dplyr::select(iris, -Sepal.Width)
 
-  get_data(MySurvey, phase = 2, slot = "metadata") <- list(
+  set_mw(MySurvey, phase = 2, slot = "metadata") <- list(
     strata = "Species",
     design_strata = "strata",
     id = "id",
@@ -696,7 +702,7 @@ test_that("merge_samples works when args are specified within it", {
   )
 
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
     data.frame(
       strata = unique(iris$Species),
       n_to_sample = c(5, 5, 5)
@@ -708,129 +714,20 @@ test_that("merge_samples works when args are specified within it", {
     wave = 1, "sample_strata"
   ) # get samples
 
-  samples <- get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
+  samples <- get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
 
-  get_data(MySurvey, phase = 2, wave = 1, slot = "sampled_data") <-
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "sampled_data") <-
     dplyr::select(iris, id, Sepal.Width)[samples, ]
 
   MySurvey <- apply_multiwave(MySurvey,
     phase = 2, wave = 1,
     fun = "merge_samples", id = "id",
-    sampled_ind = "already_sampled_ind"
+    phase_sample_ind = "already_sampled_ind"
   )
 
   expect_equal(
     dim(MySurvey@phases$phase2@waves$wave1@data),
-    c(60, 5)
-  )
-  expect_equal(length(
-    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind`[
-      MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind` == 1
-    ]
-  ), 15)
-  expect_equal(length(
-    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind`[
-      !is.na(MySurvey@phases$phase2@waves$wave1@data$Sepal.Width)
-    ]
-  ), 15)
-})
-
-test_that("merge_samples works with args specifies in metadata", {
-  MySurvey <- new_multiwave(phases = 2, waves = c(1, 3))
-
-  get_data(MySurvey, phase = 1, slot = "data") <-
-    dplyr::select(iris, -Sepal.Width)
-
-  get_data(MySurvey, phase = NA, slot = "metadata") <- list(
-    strata = "Species",
-    design_strata = "strata",
-    id = "id",
-    n_allocated = "n_to_sample"
-  )
-
-
-  get_data(MySurvey, phase = 2, wave = 1, slot = "design") <-
-    data.frame(
-      strata = unique(iris$Species),
-      n_to_sample = c(5, 5, 5)
-    )
-
-  set.seed(123)
-  MySurvey <- apply_multiwave(MySurvey,
-    phase = 2,
-    wave = 1, "sample_strata"
-  ) # get samples
-
-  samples <- get_data(MySurvey, phase = 2, wave = 1, slot = "samples")
-
-  get_data(MySurvey, phase = 2, wave = 1, slot = "sampled_data") <-
-    dplyr::select(iris, id, Sepal.Width)[samples, ]
-
-  get_data(MySurvey, phase = NA, slot = "metadata") <- list(
-    id = "id",
-    sampled_ind = "already_sampled_ind"
-  )
-
-  MySurvey <- apply_multiwave(MySurvey,
-    phase = 2, wave = 1,
-    fun = "merge_samples"
-  )
-
-  expect_equal(
-    dim(MySurvey@phases$phase2@waves$wave1@data),
-    c(60, 5)
-  )
-  expect_equal(length(
-    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind`[
-      MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind` == 1
-    ]
-  ), 15)
-  expect_equal(length(
-    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind`[
-      !is.na(MySurvey@phases$phase2@waves$wave1@data$Sepal.Width)
-    ]
-  ), 15)
-
-  # But phase metadata overrides it
-  get_data(MySurvey, phase = 2, slot = "metadata") <- list(
-    id = "id",
-    sampled_ind = "already_sampled_ind1"
-  )
-
-  MySurvey <- apply_multiwave(MySurvey,
-    phase = 2, wave = 1,
-    fun = "merge_samples"
-  )
-
-  expect_equal(
-    dim(MySurvey@phases$phase2@waves$wave1@data),
-    c(60, 5)
-  )
-  expect_equal(length(
-    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind1`[
-      MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind1` == 1
-    ]
-  ), 15)
-  expect_equal(length(
-    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind1`[
-      !is.na(MySurvey@phases$phase2@waves$wave1@data$Sepal.Width)
-    ]
-  ), 15)
-
-  # But wave metadata overrides it
-  get_data(MySurvey, phase = 2, wave = 1, slot = "metadata") <- list(
-    id = "id",
-    sampled_ind = "already_sampled_ind2"
-  )
-
-  MySurvey <- apply_multiwave(MySurvey,
-    phase = 2, wave = 1,
-    fun = "merge_samples"
-  )
-
-  expect_equal(
-    dim(MySurvey@phases$phase2@waves$wave1@data),
-    c(60, 5)
+    c(60, 6)
   )
   expect_equal(length(
     MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind2`[
@@ -843,3 +740,132 @@ test_that("merge_samples works with args specifies in metadata", {
     ]
   ), 15)
 })
+
+test_that("merge_samples works with args specifies in metadata", {
+  MySurvey <- multiwave(phases = 2, waves = c(1, 3))
+
+  set_mw(MySurvey, phase = 1, slot = "data") <-
+    dplyr::select(iris, -Sepal.Width)
+
+  set_mw(MySurvey, phase = NA, slot = "metadata") <- list(
+    strata = "Species",
+    design_strata = "strata",
+    id = "id",
+    n_allocated = "n_to_sample",
+    include_probs = FALSE
+  )
+
+
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "design") <-
+    data.frame(
+      strata = unique(iris$Species),
+      n_to_sample = c(5, 5, 5),
+      probs = rep(0.25, times = 3)
+    )
+
+  set.seed(123)
+  MySurvey <- apply_multiwave(MySurvey,
+    phase = 2,
+    wave = 1, "sample_strata", probs = "probs"
+  ) # get samples
+
+  samples <- get_mw(MySurvey, phase = 2, wave = 1, slot = "samples")$ids
+
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "sampled_data") <-
+    dplyr::select(iris, id, Sepal.Width)[samples, ]
+
+  set_mw(MySurvey, phase = NA, slot = "metadata") <- list(
+    id = "id",
+    phase_sample_ind = "already_sampled_ind",
+    wave_sample_ind = "test"
+  )
+
+  MySurvey <- apply_multiwave(MySurvey,
+    phase = 2, wave = 1,
+    fun = "merge_samples"
+  )
+
+  expect_equal(
+    dim(MySurvey@phases$phase2@waves$wave1@data),
+    c(60, 6)
+  )
+  expect_equal(length(
+    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind2`[
+      MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind2` == 1
+    ]
+  ), 15)
+  expect_equal(length(
+    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_ind2`[
+      !is.na(MySurvey@phases$phase2@waves$wave1@data$Sepal.Width)
+    ]
+  ), 15)
+  expect_equal(length(
+    MySurvey@phases$phase2@waves$wave1@data$`test2.1`[
+      MySurvey@phases$phase2@waves$wave1@data$`test2.1` == 1
+    ]
+  ), 15)
+
+  # But phase metadata overrides it
+  set_mw(MySurvey, phase = 2, slot = "metadata") <- list(
+    id = "id",
+    phase_sample_ind = "already_sampled_indA",
+    wave_sample_ind = "testA", include_probs = TRUE
+  )
+
+  MySurvey <- apply_multiwave(MySurvey,
+    phase = 2, wave = 1,
+    fun = "merge_samples", include_probs = TRUE
+  )
+
+  expect_equal(
+    dim(MySurvey@phases$phase2@waves$wave1@data),
+    c(60, 7)
+  )
+  expect_equal(length(
+    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_indA2`[
+      MySurvey@phases$phase2@waves$wave1@data$`already_sampled_indA2` == 1
+    ]
+  ), 15)
+  expect_equal(length(
+    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_indA2`[
+      !is.na(MySurvey@phases$phase2@waves$wave1@data$Sepal.Width)
+    ]
+  ), 15)
+  expect_equal(length(
+    MySurvey@phases$phase2@waves$wave1@data$`testA2.1`[
+      MySurvey@phases$phase2@waves$wave1@data$`testA2.1` == 1
+    ]
+  ), 15)
+
+  # But wave metadata overrides it
+  set_mw(MySurvey, phase = 2, wave = 1, slot = "metadata") <- list(
+    id = "id",
+    phase_sample_ind = "already_sampled_indB",
+    wave_sample_ind = "testB"
+  )
+
+  MySurvey <- apply_multiwave(MySurvey,
+    phase = 2, wave = 1,
+    fun = "merge_samples"
+  )
+
+  expect_equal(
+    dim(MySurvey@phases$phase2@waves$wave1@data),
+    c(60, 7)
+  )
+  expect_equal(length(
+    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_indB2`[
+      MySurvey@phases$phase2@waves$wave1@data$`already_sampled_indB2` == 1
+    ]
+  ), 15)
+  expect_equal(length(
+    MySurvey@phases$phase2@waves$wave1@data$`already_sampled_indB2`[
+      !is.na(MySurvey@phases$phase2@waves$wave1@data$Sepal.Width)
+    ]
+  ), 15)
+  expect_equal(length(
+    MySurvey@phases$phase2@waves$wave1@data$`testB2.1`[
+      MySurvey@phases$phase2@waves$wave1@data$`testB2.1` == 1
+    ]
+  ), 15)
+})
